/******************************************************************/
/* ACM ICPC 2012-2013                                             */
/* Northeastern European Regional Contest                         */
/* St Petersburg - Barnaul - Tashkent - Tbilisi, December 2, 2012 */
/******************************************************************/
/* Problem I. Identification of Protein                           */
/*                                                                */
/* Original idea         Mikhail Dvorkin                          */
/* Problem statement     Mikhail Dvorkin                          */
/* Test set              Mikhail Dvorkin                          */
/******************************************************************/
/* Solution                                                       */
/*                                                                */
/* Author                Roman Elizarov                           */
/******************************************************************/

import java.io.*;
import java.util.Arrays;
import java.util.Locale;

/**
 * Solution for NEERC'2012 Problem I: Identification of protein
 * This solution checks correctness of the input.
 *
 * @author Roman Elizarov
 */
public class identification_re {
    private static final boolean DEBUG = false;

    private static final int MAX_N = 100_000;
    private static final int MAX_K = 400;
    private static final long MUL = 100_000;
    private static final long P = fix(97.05276);
    private static final long Q = fix(128.05858);
    private static final long MAX_M = MAX_K * Q;

    private static final long GCD;
    private static final long PR;
    private static final long QR;

    // solution to P*U + Q*V == GCD and PR*U + QR*V == 1
    private static final long U;
    private static final long V;

    static {
        assert P < Q; // P is smaller of two

        long p = P;
        long q = Q;
        long up = 1;
        long vp = 0;
        long uq = 0;
        long vq = 1;
        // invariant: p = P*up + Q*vp ; q = P*uq + Q*vq
        while (q != 0) {
            long m = p / q;
            long r = p % q;
            //  r = p - q * m

            p = q;
            long up2 = uq;
            long vp2 = vq;

            q = r;
            uq = up - uq * m;
            vq = vp - vq * m;

            up = up2;
            vp = vp2;
        }
        GCD = p;
        PR = P / GCD;
        QR = Q / GCD;
        U = up;
        V = vp;
        assert PR * U + QR * V == 1; // sanity check
        assert PR > MAX_K; // unique (p,q) representation of any possible mass
    }

    private static long fix(double x) {
        long fix = Math.round(x * MUL);
        assert x == (double) fix / MUL : "5 digits only";
        return fix;
    }

    public static void main(String[] args) throws Exception {
        new identification_re().go();
    }

    void go() throws Exception {
        long time = System.currentTimeMillis();
        read();
        solve();
        write();
        System.out.printf("Done in %d ms%n", System.currentTimeMillis() - time);
    }

    int n;
    long[] a;

    void read() throws Exception {
        Scanner in = new Scanner(new File("identification.in"));
        in.useLocale(Locale.US);
        n = in.nextInt();
        assert n >= 1 && n <= MAX_N;
        in.nextLine();
        a = new long[n];
        for (int i = 0; i < n; i++) {
            a[i] = fix(in.nextDouble());
            assert a[i] > 0 && a[i] <= MAX_M : a[i] + " in range";
            in.nextLine();
        }
        in.close();
    }

    Res full;
    int k;
    int[][] w;
    int[][][] s;
    StringBuilder sb = new StringBuilder();

    void solve() {
        Arrays.sort(a);
        for (int i = 1; i < n; i++)
            assert a[i - 1] != a[i] : "distinct peaks";
        // resolve largest peak
        full = resolve(a[n - 1]);
        assert full != null : "max peak";
        k = full.p + full.q;
        assert k <= MAX_K : "total length";
        if (DEBUG)
            System.out.printf("%d is (%d, %d) -- full protein with %d amino acids%n", a[n - 1], full.p, full.q, k);
        // compute weights
        w = new int[full.p + 1][full.q + 1];
        // resolve all but max
        for (int i = 0; i < n - 1; i++) {
            Res res = resolve(a[i]);
            if (res == null || res.p > full.p || res.q > full.q) {
                if (DEBUG)
                    System.out.printf("%d is noise%n", a[i]);
                continue; // noise
            }
            w[res.p][res.q]++;
            if ((res.p + res.q) * 2 != k) // make sure to count main diagonal for even k just once
                w[full.p - res.p][full.q - res.q]++;
            if (DEBUG)
                System.out.printf("%d is (%d, %d) and (%d, %d) %n", a[i], res.p, res.q, full.p - res.p, full.q - res.q);
        }
        // compute chains
        int md = k / 2;
        s = new int[md + 1][full.p + 1][full.p + 1];

        for (int d = 1; d <= md; d++) {
            int fromP1 = Math.max(0, d - full.q);
            int toP1 = Math.min(d, full.p);
            for (int p1 = fromP1; p1 <= toP1; p1++) {
                int q1 = d - p1;
                int w1 = w[p1][q1];
                int fromP2 = fromP1;
                int toP2 = Math.min(toP1, full.p - p1);
                for (int p2 = fromP2; p2 <= toP2; p2++) {
                    int q2 = d - p2;
                    int ss = Integer.MIN_VALUE;
                    if (valid(d - 1, p1, p2))
                        ss = Math.max(ss, s[d - 1][p1][p2]);
                    if (valid(d - 1, p1, p2 - 1))
                        ss = Math.max(ss, s[d - 1][p1][p2 - 1]);
                    if (valid(d - 1, p1 - 1, p2))
                        ss = Math.max(ss, s[d - 1][p1 - 1][p2]);
                    if (valid(d - 1, p1 - 1, p2 - 1))
                        ss = Math.max(ss, s[d - 1][p1 - 1][p2 - 1]);
                    ss += w1;
                    if (p2 != p1)
                        ss += w[p2][q2];
                    s[d][p1][p2] = ss;
                }
            }
        }
        // solve
        int fromP1 = Math.max(0, md - full.q);
        int toP1 = Math.min(md, full.p);
        int bestS = -1;
        int bestP1 = -1;
        int bestP2 = -1;
        // find best
        if (k % 2 == 0) {
            // even length
            for (int p1 = fromP1; p1 <= toP1; p1++) {
                int p2 = full.p - p1;
                int ss = s[md][p1][p2];
                if (ss > bestS) {
                    bestS = ss;
                    bestP1 = p1;
                    bestP2 = p2;
                }
            }
        } else {
            // odd length -- figure out middle 'P' or 'Q'
            sb.append('?');
            for (int p1 = fromP1; p1 <= toP1; p1++) {
                int p2 = full.p - p1;
                // try middle 'Q'
                if (valid(md, p1, p2)) {
                    int ss = s[md][p1][p2];
                    if (ss > bestS) {
                        bestS = ss;
                        bestP1 = p1;
                        bestP2 = p2;
                        sb.setCharAt(0, 'Q');
                    }
                }
                // try middle 'P'
                if (valid(md, p1, p2 - 1)) {
                    int ss = s[md][p1][p2 - 1];
                    if (ss > bestS) {
                        bestS = ss;
                        bestP1 = p1;
                        bestP2 = p2 - 1;
                        sb.setCharAt(0, 'P');
                    }
                }
            }
        }
        if (DEBUG) {
            System.out.printf("Explained %d peaks, including max peak%n", bestS + 1);
            System.out.printf("Found solution with (%d, %d) prefix and (%d, %d) suffix %n", bestP1, md - bestP1, bestP2, md - bestP2);
        }
        // resolve the rest of prefix & suffix
        assert bestS >= 0;
        int p1 = bestP1;
        int p2 = bestP2;
        for (int d = md; d > 0; d--) {
            int q1 = d - p1;
            int q2 = d - p2;
            int ss = s[d][p1][p2];
            ss -= w[p1][q1];
            if (p2 != p1)
                ss -= w[p2][q2];
            if (valid(d - 1, p1, p2) && ss == s[d - 1][p1][p2]) {
                sb.append('Q');
                sb.insert(0, 'Q');
            } else if (valid(d - 1, p1, p2 - 1) && ss == s[d - 1][p1][p2 - 1]) {
                sb.append('P');
                sb.insert(0, 'Q');
                p2--;
            } else if (valid(d - 1, p1 - 1, p2) && ss == s[d - 1][p1 - 1][p2]) {
                sb.append('Q');
                sb.insert(0, 'P');
                p1--;
            } else if (valid(d - 1, p1 - 1, p2 - 1) && ss == s[d - 1][p1 - 1][p2 - 1]) {
                sb.append('P');
                sb.insert(0, 'P');
                p1--;
                p2--;
            }
        }
    }

    private boolean valid(int d, int p1, int p2) {
        return valid(d, p1) && valid(d, p2);
    }

    private boolean valid(int d, int p) {
        return p >= 0 && p <= full.p && p <= d && p + full.q >= d;
    }

    static class Res {
        final int p;
        final int q;

        Res(int p, int q) {
            this.p = p;
            this.q = q;
        }
    }

    Res resolve(long m) {
        if (m % GCD != 0)
            return null;
        m /= GCD;
        // solve m = p * PR + q * QR, where gcd(PR,QR) = 1
        long p0 = U * m;
        long q0 = V * m;
        // move p0 into [0,QR) range
        long z = div(p0, QR);
        p0 -= z * QR;
        q0 += z * PR;
        if (p0 < 0 || p0 > MAX_K || q0 < 0 || q0 > MAX_K)
            return null; // noise
        return new Res((int) p0, (int) q0);
    }

    private long div(long a, long b) {
        return a >= 0 ? a / b : -((-a + b - 1) / b);
    }

    void write() throws Exception {
        PrintWriter out = new PrintWriter("identification.out");
        out.println(sb.toString());
        out.close();
    }

//----------------- just for validation ------------------

    /**
     * Strict scanner to verify 100% correspondence between input files and input file format specification.
     * It is a drop-in replacement for {@link java.util.Scanner} that could be added to a solution source
     * (cut-and-paste) without breaking its ability to work with {@link java.util.Scanner}.
     */
    public class Scanner {
        private final BufferedReader in;
        private String line = "";
        private int pos;
        private int lineNo;
        private boolean localeset;

        public Scanner(File source) throws FileNotFoundException {
            in = new BufferedReader(new FileReader(source));
            nextLine();
        }

        public void close() {
            assert line == null : "Extra data at the end of file";
            try {
                in.close();
            } catch (IOException e) {
                throw new AssertionError("Failed to close with " + e);
            }
        }

        public void nextLine() {
            assert line != null : "EOF";
            assert pos == line.length() : "Extra characters on line " + lineNo;
            try {
                line = in.readLine();
            } catch (IOException e) {
                throw new AssertionError("Failed to read line with " + e);
            }
            pos = 0;
            lineNo++;
        }

        public String next() {
            assert line != null : "EOF";
            assert line.length() > 0 : "Empty line " + lineNo;
            if (pos == 0)
                assert line.charAt(0) > ' ' : "Line " + lineNo + " starts with whitespace";
            else {
                assert pos < line.length() : "Line " + lineNo + " is over";
                assert line.charAt(pos) == ' ' : "Wrong whitespace on line " + lineNo;
                pos++;
                assert pos < line.length() : "Line " + lineNo + " is over";
                assert line.charAt(pos) > ' ' : "Line " + lineNo + " has double whitespace";
            }
            StringBuilder sb = new StringBuilder();
            while (pos < line.length() && line.charAt(pos) > ' ')
                sb.append(line.charAt(pos++));
            return sb.toString();
        }

        public int nextInt() {
            String s = next();
            assert s.length() == 1 || s.charAt(0) != '0' : "Extra leading zero in number " + s + " on line " + lineNo;
            assert s.charAt(0) != '+' : "Extra leading '+' in number " + s + " on line " + lineNo;
            try {
                return Integer.parseInt(s);
            } catch (NumberFormatException e) {
                throw new AssertionError("Malformed number " + s + " on line " + lineNo);
            }
        }

        public double nextDouble() {
            assert localeset : "Locale must be set with useLocale(Locale.US)";
            String s = next();
            assert s.length() == 1 || s.startsWith("0.") || s.charAt(0) != '0' : "Extra leading zero in number " + s + " on line " + lineNo;
            assert s.charAt(0) != '+' : "Extra leading '+' in number " + s + " on line " + lineNo;
            try {
                return Double.parseDouble(s);
            } catch (NumberFormatException e) {
                throw new AssertionError("Malformed number " + s + " on line " + lineNo);
            }
        }

        public void useLocale(Locale locale) {
            assert locale == Locale.US;
            localeset = true;
        }
    }
}

